function [bin] = AdapativeThresh(img)
%Performs locally adaptive thresholding on input image.
%Iterates over possible sensitivity factors to find the
%sensitivity value where the number of spots found changes
%the least, indicating a threshold where the foreground pixels
%are most stable. Returns the binarized image, sensitivity factor,
%and the number of spots identified.
sensitivity_factors = 0.1:0.05:0.8;
spots_found = zeros(1, length(sensitivity_factors));
for i=1:length(sensitivity_factors)
    bin_img = imbinarize(img, 'adaptive', 'Sensitivity', sensitivity_factors(i));
    [~, N] = bwlabel(bin_img);
    spots_found(i) = N;
end
min_difference = Inf;
min_index = 0;
for j=1:length(spots_found)-1
    difference = abs(spots_found(j+1)-spots_found(j));
    if difference < min_difference
        min_difference = difference;
        min_index = j+1;
    end
end
bin = imbinarize(img, 'adaptive', 'Sensitivity', sensitivity_factors(min_index));
sensitivity = sensitivity_factors(min_index);
num_spots = spots_found(min_index);

bin = bin > 0;
end

