% Author: Aparna Rajpurkar

function segmented_cells = DapiSegment(dapi, samples)
    % roughly segment the mouse cells by DAPI stain

    % get the DAPI mask
    dapi_masks = getDAPIMasks(dapi);

    % initialize
    segmented_cells_per_region = cell([length(dapi_masks) 1]);
    total_cells = 0;
    
    % get coordinates of individual DAPI coordinates
    for i=1:length(dapi_masks)
        dapi_mask = dapi_masks{i};
        sample = samples{i};

        [boxcoords, regions] = getCoordsOfComponents(dapi_mask);
        num_regions = max(regions(:));
        
        images_this_region = cell([num_regions 1]);
        
        % mask each found cell
        for c=1:num_regions
            
            [x, y] = find(regions == c);
            masked_cell = zeros([size(dapi_mask)]);
            masked_cell(x,y) = 1; 
            masked_sample = sample.*masked_cell;
    
            sub_sample = imcrop(masked_sample, boxcoords(:,c));
            images_this_region{c} = sub_sample;
        end

        % add to a temporary data structure
        segmented_cells_per_region{i} = images_this_region;
        total_cells = total_cells + length(images_this_region);
    end
    
    % build real data structure with all cells
    % now that we know how many there are in the image

    segmented_cells = cell([total_cells 1]);
    counter = 1;
    
    for j=1:length(dapi_masks)
        curr_region = segmented_cells_per_region{j};
        
        for k=1:length(curr_region)
            segmented_cells{counter} = curr_region{k};
            counter = counter + 1;
        end
    end
end

function dapi_masks = getDAPIMasks(dapi)
    % needed for rough cell segmentation
    dapi_masks = cell([length(dapi) 1]);
    
    for i=1:length(dapi)
        dapi_gauss = imgaussfilt(dapi{i}, 5);
        binmask = imbinarize(dapi_gauss, graythresh(dapi_gauss)); 
        binmask = binmask > 0;
        dapi_masks{i} = binmask;
    end
end
