function [bin] = GraphCutSegment(img)
% This method uses GraphCut, a wrapper function
% for MATLAB of an algorithm implemented in C
% by image processing researchers (cited in paper and
% listed in GraphCut.m comments). We define a data cost 
% function around the mean intensity and a weighted
% smoothness cost for neighboring pixels.
% The binarized image is returned.
data_cost = zeros(size(img, 1), size(img, 2), 2);
data_cost(:, :, 1) = img > graythresh(img);
data_cost(:, :, 2) = img < graythresh(img);
lambda = 0.001;
smoothness_cost = [0, 1; 1 0];
gch = GraphCut('open', data_cost, lambda*smoothness_cost);
[gch, bin] = GraphCut('expand', gch);
gch = GraphCut('close', gch);
bin = bin > 0;
end

