% Author: Aparna Rajpurkar

function [coords, regionlabels] = getCoordsOfComponents(binmask)
    % given a binary image, find connected components and return
    % a set of coordinates that draws a box around each CC
    % as well as the region labels

    regions = regionprops(binmask);
    coords = zeros([4 length(regions)]);
    
    regionlabels = bwlabel(binmask);
    num_regions = max(regionlabels(:));
    
    for cc=1:num_regions
        [all_x, all_y] = find(regionlabels == cc);
        min_x = min(all_x);
        min_y = min(all_y);
        max_x = max(all_x);
        max_y = max(all_y);
        
        x_range = max_x - min_x;
        y_range = max_y - min_y;
        
        coords(:,cc) = [min_y min_x y_range x_range];
    end
end
