% Author: Aparna Rajpurkar

function [positions, fullbins] = runFuncsOnImgs(merfish, funcs_list, ensemble_list)
    % function to run all the algorithms, both core and ensemble, on all the images

    % initalize
    num_funcs = length(funcs_list) + length(ensemble_list);
    positions = cell([length(merfish) num_funcs]);

    fullbins = cell([length(merfish) num_funcs]);

    % iterate over all images
    % this function works for any kind of input grey level image
    % despite the variable name being 'merfish'

    for i=1:length(merfish)
       curr_img = merfish{i};
       
       % run the non-ensemble funcs first
       for j=1:length(funcs_list)
           curr_func = funcs_list{j};
           binimg = curr_func(curr_img);
           
           fullbins{i,j} = binimg;
           
           centmask = getCentroidMask(binimg);
           positions{i,j} = centmask;
       end
       
       % run the ensemble funcs
       curr_pos = length(funcs_list);
        
       for k=1:length(ensemble_list);
           curr_func = ensemble_list{k};
           binimg = curr_func({positions{i,1:curr_pos}});
           
           fullbins{i,curr_pos + k} = binimg;
           
           centmask = getCentroidMask(binimg);
           positions{i,curr_pos + k} = centmask;
           
       end
        
    end

end
